# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-19 20:18
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('rest_survey', '0004_otheranswer_surveyed'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='otheranswer',
            unique_together=set([('question', 'surveyed')]),
        ),
    ]
