# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-19 14:16
from __future__ import unicode_literals

from django.db import migrations
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('rest_survey', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='answer',
            name='value',
            field=jsonfield.fields.JSONField(null=True, verbose_name='Value'),
        ),
    ]
