# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-19 13:10
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('rest_survey', '0003_auto_20170619_0928'),
    ]

    operations = [
        migrations.AddField(
            model_name='otheranswer',
            name='surveyed',
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name='others',
                to='rest_survey.SurveyedObject'),
            preserve_default=False,
        ),
    ]
