# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-19 14:28
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('rest_survey', '0002_auto_20170619_0916'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='answer',
            unique_together=set([('surveyed', 'question')]),
        ),
    ]
